@@ -373,10 +373,24 @@ Receive remote control commands for worker.
 
   my $worker_id = $backend->register_worker;
   my $worker_id = $backend->register_worker($worker_id);
+  my $worker_id = $backend->register_worker(
+    $worker_id, {status => {queues => ['default', 'important']}});
 
 Register worker or send heartbeat to show that this worker is still alive.
 Meant to be overloaded in a subclass.
 
+These options are currently available:
+
+=over 2
+
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
+=back
+
 =head2 remove_job
 
   my $bool = $backend->remove_job($job_id);
@@ -402,9 +416,8 @@ Reset job queue. Meant to be overloaded in a subclass.
   my $bool = $backend->retry_job($job_id, $retries);
   my $bool = $backend->retry_job($job_id, $retries, {delay => 10});
 
-Transition from C<failed> or C<finished> state back to C<inactive>, already
-C<inactive> jobs may also be retried to change options. Meant to be overloaded
-in a subclass.
+Transition job back to C<inactive> state, already C<inactive> jobs may also be
+retried to change options. Meant to be overloaded in a subclass.
 
 These options are currently available:
 
@@ -536,6 +549,12 @@ Process id of worker.
 
 Epoch time worker was started.
 
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
 =back
 
 =head1 SEE ALSO
