@@ -104,13 +104,14 @@ sub receive {
 }
 
 sub register_worker {
-  my ($self, $id) = @_;
+  my ($self, $id, $options) = (shift, shift, shift || {});
 
   return $self->pg->db->query(
-    "insert into minion_workers (id, host, pid)
-     values (coalesce(?, nextval('minion_workers_id_seq')), ?, ?)
-     on conflict(id) do update set notified = now()
-     returning id", $id, $self->{host} //= hostname, $$
+    q{insert into minion_workers (id, host, pid, status)
+      values (coalesce($1, nextval('minion_workers_id_seq')), $2, $3, $4)
+      on conflict(id) do update set notified = now(), status = $4
+      returning id}, $id, $self->{host} //= hostname, $$,
+    {json => $options->{status} // {}}
   )->hash->{id};
 }
 
@@ -174,7 +175,6 @@ sub retry_job {
        priority = coalesce(?, priority), queue = coalesce(?, queue),
        retried = now(), retries = retries + 1, state = 'inactive'
      where id = ? and retries = ?
-       and state in ('inactive', 'failed', 'finished')
      returning 1", $options->{delay} // 0, @$options{qw(priority queue)}, $id,
     $retries
   )->rows;
@@ -212,10 +212,10 @@ sub worker_info {
     "select id, extract(epoch from notified) as notified, array(
        select id from minion_jobs
        where state = 'active' and worker = minion_workers.id
-     ) as jobs, host, pid, extract(epoch from started) as started
+     ) as jobs, host, pid, status, extract(epoch from started) as started
      from minion_workers
      where id = ?", shift
-  )->hash;
+  )->expand->hash;
 }
 
 sub _try {
@@ -585,9 +585,23 @@ Receive remote control commands for worker.
 
   my $worker_id = $backend->register_worker;
   my $worker_id = $backend->register_worker($worker_id);
+  my $worker_id = $backend->register_worker(
+    $worker_id, {status => {queues => ['default', 'important']}});
 
 Register worker or send heartbeat to show that this worker is still alive.
 
+These options are currently available:
+
+=over 2
+
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
+=back
+
 =head2 remove_job
 
   my $bool = $backend->remove_job($job_id);
@@ -611,8 +625,8 @@ Reset job queue.
   my $bool = $backend->retry_job($job_id, $retries);
   my $bool = $backend->retry_job($job_id, $retries, {delay => 10});
 
-Transition from C<failed> or C<finished> state back to C<inactive>, already
-C<inactive> jobs may also be retried to change options.
+Transition job back to C<inactive> state, already C<inactive> jobs may also be
+retried to change options.
 
 These options are currently available:
 
@@ -750,6 +764,12 @@ Process id of worker.
 
 Epoch time worker was started.
 
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
 =back
 
 =head1 SEE ALSO
@@ -852,5 +872,6 @@ alter table minion_workers add column inbox jsonb
 -- 13 up
 create index on minion_jobs using gin (parents);
 
--- 14 up
-drop index minion_jobs_parents_idx;
+-- 15 up
+alter table minion_workers add column status jsonb
+  check(jsonb_typeof(status) = 'object') default '{}';
